package main

// An app to submit patches for the 30 GO GUI repos

import (
	"strings"

	"go.wit.com/dev/alexflint/arg"
	"go.wit.com/gui"
	"go.wit.com/lib/protobuf/forgepb"
	"go.wit.com/lib/protobuf/gitpb"
	"go.wit.com/log"
)

// sent via -ldflags
var VERSION string
var BUILDTIME string

// using this for now. triggers config save
var configSave bool

func getVersion(repo *gitpb.Repo, name string) string {
	cmd := []string{"git", "describe", "--tags", "--always", name}
	result := repo.RunQuiet(cmd)
	output := strings.Join(result.Stdout, "\n")
	log.Info("cmd =", cmd, output)

	return strings.TrimSpace(output)
}

func main() {
	me = new(mainType)
	me.pp = arg.MustParse(&argv)
	me.urlbase = argv.URL
	if me.urlbase == "" {
		me.urlbase = "https://go.wit.com/"
	}
	me.urlbase = strings.Trim(me.urlbase, "/") // track down why trailing '/' makes http POST not work

	// load the ~/.config/forge/ config
	me.forge = forgepb.Init()
	me.found = new(gitpb.Repos)

	if argv.User {
		me.forge.CheckoutUser()
		okExit("")
	}

	if argv.Master {
		me.forge.CheckoutMaster()
		okExit("")
	}

	if argv.Register != "" {
		if err := doRegister(argv.Register); err == nil {
			okExit("attempting to register " + argv.Register)
		} else {
			badExit(err)
		}
	}

	if argv.Delete != "" {
		me.forge.DeleteByGoPath(argv.Delete)
		me.forge.SetConfigSave(true)
		okExit("")
	}

	if argv.Fix {
		okExit("")
	}

	// first find the repos or gopaths to operate on
	if argv.Config {
		if findConfig() {
			me.forge.ConfigPrintTable()
			okExit("")
		}
	} else {
		findRepos()
	}
	// okExit("")

	log.Info("found", me.found.Len(), "repos. found", len(me.foundPaths), "paths from .config/forge")

	// now, do something to all of them (or just print out a table of them)
	var done bool = false
	if argv.Do != nil {
		if argv.Do.Dirty {
			doCheckDirty()
			okExit("")
			done = true
		}

		if argv.Do.Scan {
			doScan()
			done = true
		}

		if argv.Do.GitPull {
			doGitPull()
			done = true
		}

		if argv.Do.GitReset {
			doGitReset()
			done = true
		}

		if argv.Do.List {
			// print out the repos
			doCobol()
			done = true
		}
		if argv.Do.PatchSet != "" {
			sendDevelDiff(argv.Do.PatchSet)
			// sendMasterDiff()
			okExit("patches")
		}
	}

	if argv.ListPatchSet {
		listPatches()
		okExit("patches")
	}

	if configSave {
		me.forge.ConfigSave()
		configSave = false
	}

	// if the user doesn't want to open the GUI and
	// nothing else was specified to be done,
	// then just list the table to stdout
	if gui.NoGui() {
		if !done {
			// if nothing was selected, print out a table of them on STDOUT
			doCobol()
			okExit("")
		}
	}
	// open the gui
	doGui()
	okExit("")
}
